@@ -100,9 +100,9 @@ sub mk_fcode {
     #      or die "Unknown block_type $name. Try =use ...";
     #get prop
     my $block = $mod_name->new(
-        name    => $name,
-        context => $self->current_context,
-        options => $pod_opt,
+        name          => $name,
+        context       => $self->current_context,
+        options       => $pod_opt,
         class_options => $self->current_context->class_opts->{ $name . "<>" }
     );
 
@@ -127,7 +127,9 @@ sub parse {
     my $src        = shift;
     my $need_close = 0;
     unless ( ref $src ) {
-        $src = new IO::File:: $src , 'r' or die "Eror open file: $!";
+        # set current file
+        my $filepath = ( $self->current_context->custom->{src} = $src ) || '';
+        $src = new IO::File:: $src , 'r' or die "Eror open file:$filepath $!";
         $need_close = 1;
     }
     if ( ref $src eq 'SCALAR' ) {
@@ -176,6 +178,7 @@ sub on_end_element {
 sub on_end_block {
     my $self = shift;
     my $blk  = shift;
+
     $blk->end( $self, $blk->get_attr() );
     return $blk;
 
@@ -201,13 +204,52 @@ sub begin_input {
 
 sub end_input {
     my $self = shift;
+    #begin flush for footers
+    if ( my $f = $self->{CODE_N_HASH} ) {
+        my $pod = "=begin _NOTES_\n";
+        foreach my $num ( sort keys %$f ) {
+            my $note = $f->{$num};
+            $pod .= "$num\t$note->{text}\n";
+        }
+        $pod .= "=end _NOTES_\n";
+        $self->_parse_chunk( \$pod );
+    }
     $self->end_document;
 }
 
 sub start_block {
     my $self = shift;
-    my ( $name, $opt, $str_num ) = @_;
+    my ( $name, $opt, $str_num, $pelem, $first_line ) = @_;
+
+    #use item1 as item with attibute level
+    my $list_level;
+    if ( $name =~ /^item(\d+)/ ) {
+
+        #save level
+        $list_level = $1;
+
+        #rename block item123 to item
+        $name = 'item';
+    }
     my $elem = ref($name) ? $name : $self->mk_block( $name, $opt );
+
+    #set lists level in attributes
+    if ( defined $list_level ) {
+        $elem->attrs_by_name->{level} = $list_level;
+    }
+
+    #save line num
+    $elem->context->custom->{_line_num_} = $str_num;
+
+    #save RAW header
+    if ($pelem) {
+        $elem->context->custom->{_RAW_} = $pelem->{RAW};
+    }
+    #save first_line of para ( if exists)
+    if ($first_line) {
+        $elem->context->custom->{_FIRST_PARA_LINE_} = $first_line;
+
+    }
     $self->start_element($elem);
 }
 
@@ -227,38 +269,26 @@ sub para {
     #hadnle block on_para
     if ( my $elem = $self->current_element ) {
         $txt = $elem->on_para( $self, $txt );
+        return unless defined $txt;
         if ( ref($txt) ) {
             $self->run_para($txt);
         }
         else {
             $self->_process_comm( $self->mk_characters($txt) );
         }
+
     }
 }
 
 sub end_block {
     my $self = shift;
     my ( $name, $opt, $str_num ) = @_;
-    my $elem = $self->current_element;    #mk_block($name, $opt);
+    my $elem       = $self->current_element;    #mk_block($name, $opt);
+    my $last_block = $elem->local_name;
     $self->end_element($elem);
-}
 
-sub _parse_tree_ {
-    my $self = shift;
-    my $elem = shift;
-    if ( ref($elem) ) {
-        if ( UNIVERSAL::isa( $elem, 'Pod::ParseTree' ) ) {
-            return [ map { ref($_) ? $self->_parse_tree_($_) : $_ }
-                  $elem->children ];
-        }
-        elsif ( UNIVERSAL::isa( $elem, 'Pod::InteriorSequence' ) ) {
-            my %attr = ( name => $elem->cmd_name );
-            if ( my $ptree = $elem->parse_tree ) {
-                $attr{childs} = $self->_parse_tree_($ptree);
-            }
-            return \%attr;
-        }
-    }
+    #save last processed block name
+    $self->current_context->custom->{_last_block_} = $last_block;
 }
 
 sub run_para {
@@ -302,7 +332,8 @@ sub __make_events {
                 type => 'start_fcode',
                 data => $name
               },
-              $self->__make_events( @{ $el->{childs} } ),
+              $self->__make_events(
+                ref( $el->{childs} ) ? @{ $el->{childs} } : $el->{childs} ),
               {
                 type => 'end_fcode',
                 data => $name
@@ -331,14 +362,6 @@ sub __process_events {
     }
 }
 
-sub parse_str {
-    my $self = shift;
-    my $str  = shift;
-    my $p    = new Pod::Parser::;
-    my $res  = $self->_parse_tree_( Pod::Parser->new->parse_text( $str, 123 ) );
-    return $res;
-}
-
 sub get_elements_from_ref {
     my $self = shift;
     my $ref  = shift;
@@ -363,31 +386,6 @@ sub get_elements_from_ref {
     return \@elems;
 }
 
-#process para: make tree of text
-sub parse_para {
-    my $self = shift;
-    my @in   = $self->__expand_array_ref(@_);
-    my @out  = ();
-    foreach my $el (@in) {
-        if ( ref $el ) {
-            push @out, $el;
-        }
-        else {
-            my $elems_ref = $self->parse_str($el);
-            foreach my $item (@$elems_ref) {
-                unless ( ref($item) ) {
-
-                    #got characters
-                    $item = { data => $item, type => 'para' };
-                }
-
-                push @out, $item;
-            }
-        }
-    }
-    return \@out;
-}
-
 #make XML::ExtOn objects from array
 sub _make_elements {
     my $self = shift;
