@@ -75,7 +75,7 @@ use Perl6::Pod::To::XHTML::ProcessHeadings;
 use Perl6::Pod::To::XHTML::MakeHead;
 use Perl6::Pod::To::XHTML::MakeBody;
 use Perl6::Pod::Parser::Doformatted;
-use Perl6::Pod::Parser::Doallow;
+use Perl6::Pod::Parser::NestedAttr;
 use XML::ExtOn('create_pipe');
 use base qw/Perl6::Pod::To::XML/;
 use constant POD_URI => 'http://perlcabal.org/syn/S26.html';
@@ -100,12 +100,9 @@ sub new {
     $self->{out_put} =
       create_pipe( 'Perl6::Pod::To::XHTML::ProcessHeadings', $self->{out_put} );
     return create_pipe(
-        'Perl6::Pod::Parser::Doformatted',
-        'Perl6::Pod::Parser::Doallow',
-        'Perl6::Pod::Parser::ListLevels',
-        'Perl6::Pod::Parser::AddHeadLevels',
-        'Test::Filter',
-        $self
+        'Perl6::Pod::Parser::NestedAttr', 'Perl6::Pod::Parser::Doformatted',
+        'Perl6::Pod::Parser::ListLevels', 'Perl6::Pod::Parser::AddHeadLevels',
+        'Test::Filter',                   $self
     );
 }
 
@@ -130,8 +127,9 @@ sub start_document {
 }
 
 sub end_document {
-    if ( my $out = $_[0]->out_parser ) {
-        my $root = $out->mk_element( $_[0]->{doctype} || 'html' );
+    my $self = shift;
+    if ( my $out = $self->out_parser ) {
+        my $root = $out->mk_element( $self->{doctype} || 'html' );
         $out->end_element($root);
         $out->end_document;
     }
@@ -164,7 +162,11 @@ sub process_element {
         }
     }
     else {
-
+        #skip all _UPPER_CASE_SPESIAL_ tags
+        my $lname = $elem->local_name();
+        if (  $lname eq uc($lname) and $lname=~ /^_+.*_$/ ) {
+            return [ $self->_make_elements(@_) ]
+        }
         #make characters from unhandled texts
         my @out_content = ();
         for (@_) {
@@ -227,23 +229,26 @@ sub _make_events {
     my @in   = $self->__expand_array_ref(@_);
     my @out  = ();
     foreach my $elem (@in) {
-        push @out, ref($elem) ? $elem : $self->mk_characters($self->_html_escape($elem));
+        push @out, ref($elem)
+          ? $elem
+          : $self->mk_characters( $self->_html_escape($elem) );
     }
     return @out;
 }
 
-sub export_block_item {
+sub export_block__DEFN_TERM_ {
     my ( $self, $el, @p ) = @_;
-    my $elem =
-      $self->mk_element('listitem')->add_content( $self->_make_events(@p) );
 
-    #add POD attr for use in export_block_itemlist
-    #for varlistentry
-    $elem->{POD} = $el->get_attr;
-    return $elem;
+    return $self->mk_element('strong')->add_content( $self->_make_events(@p) )
+      ->insert_to( $self->mk_element('dt') );
 }
 
-sub export_block_itemlist {
+# <item> - $self->current_root_element
+#  <_ITEM_ENTRY_>
+#       ...
+#  </_ITEM_ENTRY_>
+# </item>
+sub export_block__ITEM_ENTRY_ {
     my ( $self, $el, @p ) = @_;
     my $attr = $el->attrs_by_name;
     my ( $list_name, $items_name ) = @{
@@ -253,36 +258,42 @@ sub export_block_itemlist {
             definition => [ 'dl', 'dd' ]
         }->{ $attr->{listtype} }
       };
-    my $list = $self->mk_element($list_name);
-    foreach (@p) {
-        next unless ref $_;
-        my $lname = $_->local_name;
-        if ( $lname eq 'listitem' ) {
-            $_->local_name($items_name);
+    my $list =
+      $self->mk_element($items_name)->add_content( $self->_make_events(@p) );
+    #check if numbered item
+    my $item_attr = $el->attrs_by_name;
+    if ( my $number =  $item_attr->{number_value}) {
+        my $value = $item_attr->{number_value};
+       $list->attrs_by_name->{value} = $value; 
+    }
+    return $list;
 
-            #if variable list, then add varlistentry
-            if ( $list->local_name eq 'dl' ) {
-                my $term = $_->{POD}->{term};
-                if ( ref($term) ) {
-                    $term = join " ", @$term;
-                }
+}
 
-                my $var_entry =
-                  $self->mk_element('dt')
-                  ->add_content( $self->mk_element('strong')
-                      ->add_content( $self->mk_characters($term) ) );
-                $var_entry->add_content($_);
-                $list->add_content($var_entry);
-
-            }
-            else {
-                $list->add_content($_);
-            }
+sub export_block__LIST_ITEM_ {
+    my ( $self, $el, @p ) = @_;
 
+    #check type of list
+    my $attr = $el->attrs_by_name;
+    my ( $list_name, $items_name ) = @{
+        {
+            ordered    => [ 'ol', 'li' ],
+            unordered  => [ 'ul', 'li' ],
+            definition => [ 'dl', 'dd' ]
+        }->{ $attr->{listtype} }
+      };
+    my $res =
+      $self->mk_element($list_name)->add_content( $self->_make_events(@p) );
+    #do nesting
+    my $item_level = $el->attrs_by_name->{item_level} || 1;
+    if ( my $count = $item_level -1 ) {
+        for (1..$count) {
+            my $nest =  $self->mk_element('blockquote');
+            $res = $nest->add_content( $res);
         }
     }
 
-    return $list;
+    return $res;
 }
 
 sub export_block_NAME {
@@ -298,6 +309,31 @@ sub export_block_NAME {
     return $head;
 }
 
+#process N footnote
+sub export_block__NOTES_ {
+    my ( $self, $el, @p ) = @_;
+    my $div = $self->mk_element('div');
+    $div->attrs_by_name->{class} = 'footnote';
+    return $div->add_content(
+        $self->mk_element('p')->add_content( $self->mk_characters("NOTES") ),
+        $self->_make_events(@p) );
+
+}
+
+sub export_block__NOTE_ {
+    my ( $self, $el, @p ) = @_;
+    my $nid = $el->attrs_by_name->{note_id};
+    my $a   = $self->mk_element('a');
+    $a->attrs_by_name->{name} = "ftn.nid${nid}";
+    $a->attrs_by_name->{href} = "#nid${nid}";
+    $a->add_content(
+        $self->mk_element('sup')->add_content( $self->mk_characters("$nid.") )
+    );
+    return $self->mk_element('p')
+      ->add_content( $a, $self->_make_events( " ", @p ) );
+
+}
+
 1;
 __END__
 
@@ -320,3 +356,4 @@ at your option, any later version of Perl 5 you may have available.
 
 =cut
 
+
